summaryrefslogtreecommitdiffstats
path: root/kjsembed/bindings/image_imp.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
commit9ba04742771370f59740e32e11c5f3a1e6a1b70a (patch)
treec81c34dae2b3b1ea73801bf18a960265dc4207f7 /kjsembed/bindings/image_imp.h
parent1a96c45b22d01378202d9dc7ed9c47acd30f966e (diff)
downloadtdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.tar.gz
tdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.zip
Initial TQt conversion
Diffstat (limited to 'kjsembed/bindings/image_imp.h')
-rw-r--r--kjsembed/bindings/image_imp.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/kjsembed/bindings/image_imp.h b/kjsembed/bindings/image_imp.h
index 39cb7031..94d84e01 100644
--- a/kjsembed/bindings/image_imp.h
+++ b/kjsembed/bindings/image_imp.h
@@ -32,7 +32,7 @@ namespace KJSEmbed {
namespace Bindings {
/**
* Methods for the TQImage binding.
*
* @author Richard Moore, rich@kde.org
* @version $Id$
@@ -66,27 +66,27 @@ public:
private:
- TQString filename() const;
- TQString format() const;
+ TTQString filename() const;
+ TTQString format() const;
int width() const;
int height() const;
int depth() const;
bool isOk() const;
- TQPixmap pixmap() const;
+ TTQPixmap pixmap() const;
- bool load( const TQString &filename );
- bool save( const TQString &filename, const TQString &fmt );
- void setFormat( const TQString &fmt );
+ bool load( const TTQString &filename );
+ bool save( const TTQString &filename, const TTQString &fmt );
+ void setFormat( const TTQString &fmt );
void smoothScale( int w, int h );
void smoothScaleMin( int w, int h );
- void setPixmap( const TQPixmap &pix );
+ void setPixmap( const TTQPixmap &pix );
int mid;
- TQImage img; // this is a temp!!!
- TQString nm;
- TQString fmt;
+ TTQImage img; // this is a temp!!!
+ TTQString nm;
+ TTQString fmt;
};
} // namespace
@@ -32,7 +32,7 @@ namespace KJSEmbed {
namespace Bindings {
/**
- * Methods for the TQImage binding.
+ * Methods for the TTQImage binding.
*
* @author Richard Moore, rich@kde.org